@@ -70,8 +70,9 @@ class InterfaceDocumenter(autodoc.ClassDocumenter):
         elif member_order == 'bysource' and self.analyzer:
             # sort by source order, by virtue of the module analyzer
             tagorder = self.analyzer.tagorder
+            name = self.object.__name__
             def keyfunc(entry):
-                return tagorder.get(entry[0], len(tagorder))
+                return tagorder.get('%s.%s' % (name, entry[0]), len(tagorder))
             members.sort(key=keyfunc)
 
         for name, desc in members:
